@@ -152,6 +152,11 @@ struct smtp_client_transaction {
 	bool submitted_data:1;
 };
 
+struct smtp_client_login_callback {
+	smtp_client_command_callback_t *callback;
+	void *context;
+};
+
 struct smtp_client_connection {
 	struct connection conn;
 	pool_t pool;
@@ -165,9 +170,11 @@ struct smtp_client_connection {
 	in_port_t port;
 	enum smtp_client_connection_ssl_mode ssl_mode;
 
+	int connect_errno;
+
 	struct smtp_client_settings set;
 	char *password;
-	ARRAY_TYPE(const_string) extra_capabilities;
+	ARRAY(struct smtp_client_capability_extra) extra_capabilities;
 
 	pool_t cap_pool;
 	struct {
@@ -176,6 +183,11 @@ struct smtp_client_connection {
 		const char **auth_mechanisms;
 		const char **xclient_args;
 		uoff_t size;
+
+		/* Lists of custom MAIL/RCPT parameters supported by peer. These
+		   arrays always end in NULL pointer once created. */
+		ARRAY_TYPE(const_string) mail_param_extensions;
+		ARRAY_TYPE(const_string) rcpt_param_extensions;
 	} caps;
 
 	struct smtp_reply_parser *reply_parser;
@@ -194,9 +206,12 @@ struct smtp_client_connection {
 	struct ssl_iostream *ssl_iostream;
 
 	enum smtp_client_connection_state state;
+	pool_t state_pool;
+	struct {
+		struct smtp_reply *login_reply;
+	} state_data;
 
-	smtp_client_command_callback_t *login_callback;
-	void *login_context;
+	ARRAY(struct smtp_client_login_callback) login_callbacks;
 
 	/* commands pending in queue to be sent */
 	struct smtp_client_command *cmd_send_queue_head, *cmd_send_queue_tail;
